max_array

Function max_array 

pub fn max_array<T, A>(array: A) -> Option<<T as ArrowPrimitiveType>::Native>
where T: ArrowNumericType, A: ArrayAccessor<Item = <T as ArrowPrimitiveType>::Native>,
Returns the max of values in the array of ArrowNumericType type, or dictionary array with value of ArrowNumericType type.